@@ -1,7 +1,7 @@
 package RDF::DOAP::Version;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = 0.006;
+our $VERSION   = 0.007;
 
 use Moose;
 extends qw(RDF::DOAP::Resource);
@@ -91,7 +91,7 @@ sub changelog_section
 			$self->_changelog_section_header,
 			map {
 				my ($head, @lines) = @$_;
-				(@lines, '');
+				(sort(@lines), '');
 			} @ss,
 		);
 	}
@@ -101,7 +101,7 @@ sub changelog_section
 		$self->_changelog_section_header,
 		map {
 			my ($head, @lines) = @$_;
-			(" [ $head ]", @lines, '');
+			(" [ $head ]", sort(@lines), '');
 		} @ss,
 	);
 }
